Module patch

Module patch 

Cargo patch management for local development.

This module provides functionality to patch git dependencies to use local paths during development, and restore them when done.

Structs

GitDependency
Information about a git dependency that can be patched.
PatchManager
Manager for Cargo patch operations.
PatchReport
Report from applying patches.
ResetReport
Report from removing patches.