Cargo patch management for local development.
This module provides functionality to patch git dependencies to use local paths during development, and restore them when done.
Structs
- GitDependency
- Information about a git dependency that can be patched.
- Patch
Manager - Manager for Cargo patch operations.
- Patch
Report - Report from applying patches.
- Reset
Report - Report from removing patches.